@@ -7,16 +7,23 @@ from badsecrets.base import BadsecretsBase
 
 class Flask_SignedCookies(BadsecretsBase):
     identify_regex = re.compile(r"eyJ(?:[\w-]*\.)(?:[\w-]*\.)[\w-]*")
-    description = {"Product": "Flask Signed Cookie", "Secret": "Flask Password"}
+    description = {"product": "Flask Signed Cookie", "secret": "Flask Password", "severity": "HIGH"}
 
     def check_secret(self, flask_cookie):
         if not self.identify(flask_cookie):
             return None
-        for l in set(
-            list(self.load_resource("flask_secret_keys.txt")) + list(self.load_resource("top_10000_passwords.txt"))
-        ):
+        for l in set(list(self.load_resources(["flask_secret_keys.txt", "top_10000_passwords.txt"]))):
             password = l.rstrip()
             r = flaskVerify(value=flask_cookie, secret=password)
             if r:
                 return {"secret": password, "details": r}
         return None
+
+    def get_hashcat_commands(self, flask_cookie, *args):
+        return [
+            {
+                "command": f"hashcat -m 29100 -a 0 {flask_cookie} <dictionary_file>",
+                "description": f"Flask Signed Cookie",
+                "severity": "HIGH",
+            }
+        ]
